@@ -14,18 +14,17 @@
 #' @param x a data tbl
 #' @param name name of temporary table on database.
 #' @param ... other arguments passed on to methods
+#' @inheritParams copy_to.src_sql
 #' @seealso \code{\link{copy_to}} which is the conceptual opposite: it
 #'   takes a local data frame and makes it available to the remote source.
 #' @export
 #' @examples
-#' \donttest{
 #' if (require("RSQLite") && has_lahman("sqlite")) {
-#' batting <- tbl(lahman_sqlite(), "Batting")
-#' remote <- select(filter(batting, yearID > 2010 && stint == 1), playerID:H)
-#' remote2 <- collapse(remote)
-#' cached <- compute(remote)
-#' local  <- collect(remote)
-#' }
+#'   batting <- tbl(lahman_sqlite(), "Batting")
+#'   remote <- select(filter(batting, yearID > 2010 && stint == 1), playerID:H)
+#'   remote2 <- collapse(remote)
+#'   cached <- compute(remote)
+#'   local  <- collect(remote)
 #' }
 compute <- function(x, name = random_table_name(), ...) {
   UseMethod("compute")
@@ -58,8 +57,9 @@ collapse.tbl_sql <- function(x, vars = NULL, ...) {
 }
 
 #' @export
-compute.tbl_sql <- function(x, name = random_table_name(), ...) {
-  x$query$save_into(name)
+#' @rdname compute
+compute.tbl_sql <- function(x, name = random_table_name(), temporary = TRUE, ...) {
+  x$query$save_into(name, temporary = temporary)
   update(tbl(x$src, name), group_by = groups(x))
 }
 
