@@ -1,4 +1,3 @@
-
 #' Select top n rows (by value).
 #'
 #' This is a convenient wrapper that uses \code{\link{filter}} and
@@ -10,17 +9,16 @@
 #'   the number of rows per group. May include more than \code{n} if there
 #'   are ties.
 #' @param wt the variable to use for ordering. If not specified, defaults to
-#'   the last varible in the tbl.
+#'   the last variable in the tbl.
 #' @export
 #' @examples
-#' if (require("Lahman")) {
-#'   players <- group_by(tbl_df(Batting), playerID)
-#'   games <- tally(players, G)
-#'   top_n(games, 10, n)
+#' data("Batting", package = "Lahman")
+#' players <- group_by(tbl_df(Batting), playerID)
+#' games <- tally(players, G)
+#' top_n(games, 10, n)
 #'
-#'   # A little nicer with %.%
-#'   tbl_df(Batting) %.% group_by(playerID) %.% tally(G) %.% top_n(10)
-#' }
+#' # A little nicer with %>%
+#' tbl_df(Batting) %>% group_by(playerID) %>% tally(G) %>% top_n(10)
 top_n <- function(x, n, wt = NULL) {
   if (is.null(wt)) {
     vars <- tbl_vars(x)
@@ -28,7 +26,7 @@ top_n <- function(x, n, wt = NULL) {
     wt <- as.name(vars[length(vars)])
   }
 
-  call <- substitute(filter(x, rank(desc(wt), ties.method = "min") < n),
+  call <- substitute(filter(x, rank(desc(wt), ties.method = "min") <= n),
     list(n = n, wt = substitute(wt)))
 
   eval(call)
