@@ -1,11 +1,19 @@
 #' Tools for describing matrices
 #'
-#' @param x a matrix to describe
-#' @param n number of rows to show
+#' @param x Object to show.
+#' @param n Number of rows to show. If \code{NULL}, the default, will print
+#'   all rows if less than option \code{dplyr.print_max}. Otherwise, will
+#'   print \code{dplyr.print_min}
 #' @keywords internal
 #' @examples
 #' dim_desc(mtcars)
 #' trunc_mat(mtcars)
+#'
+#' print(tbl_df(mtcars))
+#' print(tbl_df(mtcars), n = 1)
+#' print(tbl_df(mtcars), n = 3)
+#' print(tbl_df(mtcars), n = 100)
+#'
 #' @name dplyr-formatting
 NULL
 
@@ -36,6 +44,10 @@ trunc_mat <- function(x, n = NULL) {
   df <- as.data.frame(head(x, n))
   if (nrow(df) == 0) return()
 
+  # List columns need special treatment because format can't be trusted
+  is_list <- vapply(df, is.list, logical(1))
+  df[is_list] <- lapply(df[is_list], function(x) vapply(x, obj_type, character(1)))
+
   mat <- format(df, justify = "left")
 
   width <- getOption("width")
@@ -80,14 +92,28 @@ wrap <- function(..., indent = 0) {
 
 ruler <- function() {
   x <- seq_len(getOption("width"))
-  y <- ifelse(x %% 10 == 0, x %/% 10, ifelse(x %% 5 == 0, "+", "-"))
+  y <- ifelse(x %% 10 == 0, x %>% 10, ifelse(x %% 5 == 0, "+", "-"))
   cat(y, "\n", sep = "")
   cat(x %% 10, "\n", sep = "")
 }
 
+rule <- function(char = "-") {
+  paste0(rep(char, getOption("width") - 2), collapse = "")
+}
+
 #' @export
 print.BoolResult <- function(x, ...) {
   cat(x)
   if (!x) cat(": ", attr(x, "comment"), sep = "")
   cat("\n")
 }
+
+obj_type <- function(x) {
+  if (!is.object(x)) {
+    paste0("<", type_sum(x), if (!is.array(x)) paste0("[", length(x), "]"), ">")
+  } else if (!isS4(x)) {
+    paste0("<S3:", paste0(class(x), collapse = ", "), ">")
+  } else {
+    paste0("<S4:", paste0(is(x), collapse = ", "), ">")
+  }
+}
