@@ -20,6 +20,13 @@ namespace dplyr {
             return out ;
         }
         
+        virtual SEXP process(const RowwiseDataFrame& gdf ){
+            int nrows = gdf.nrows() ;
+            
+            Vector<RTYPE> out(nrows, Vector<RTYPE>::get_na() ) ;
+            return out ;
+        }
+        
         virtual SEXP process(const FullDataFrame& df){
             int nrows = df.nrows() ;
             Vector<RTYPE> out = no_init(nrows) ;
@@ -61,6 +68,9 @@ namespace dplyr {
         virtual SEXP process(const GroupedDataFrame& gdf ){
             return promote( lead.process(gdf) ) ;
         }
+        virtual SEXP process(const RowwiseDataFrame& gdf ){
+            return promote( lead.process(gdf) ) ;
+        }
         virtual SEXP process(const FullDataFrame& df){
             return promote( lead.process(df) ) ;    
         }
