@@ -48,13 +48,17 @@ namespace dplyr {
             return hash_fun( vec[i] ) ;
         } 
         inline bool equal(int i, int j) const { 
-            return compare::is_equal( vec[i], vec[j] ) ;
+            return compare::equal_or_both_na( vec[i], vec[j] ) ;
         }
         
         inline bool less(int i, int j) const { 
             return compare::is_less( vec[i], vec[j] ) ;
         }
         
+        inline bool equal_or_both_na(int i, int j) const {
+            return compare::equal_or_both_na( vec[i], vec[j] ) ;    
+        }
+        
         inline bool greater(int i, int j) const { 
             return compare::is_greater( vec[i], vec[j] ) ;
         }
@@ -168,7 +172,7 @@ namespace dplyr {
         }
         
         inline SEXP promote(VECTOR x) const{
-            copy_attributes(x, VisitorImpl::vec ) ;
+            copy_most_attributes(x, VisitorImpl::vec ) ;
             return x ;
         }
     } ;
@@ -242,7 +246,7 @@ namespace dplyr {
         }
         
         inline SEXP promote( IntegerVector x) const {
-            copy_attributes(x, vec ) ;
+            copy_most_attributes(x, vec ) ;
             return x ;
         }
         
