@@ -8,9 +8,9 @@ class VisitorSetHash {
 public:
     size_t hash( int j) const {
         const Class& obj = static_cast<const Class&>(*this) ; 
-        size_t seed = 0 ;
+        size_t seed = obj.get(0)->hash(j) ; ;
         int n = obj.size() ;
-        for( int k=0; k<n; k++){
+        for( int k=1; k<n; k++){
             boost::hash_combine( seed, obj.get(k)->hash(j) ) ;
         }
         return seed ;
