@@ -6,6 +6,8 @@
 #include <tools/hash.h>
 #include <tools/delete_all.h>
 #include <tools/ListOf.h>
+#include <tools/StrictListOf.h>
+#include <tools/FilteredListOf.h>
 #include <tools/collapse.h>
 #include <tools/get_single_class.h>
 #include <tools/SlicingIndex.h>
